function SurveyCallback(event)
% SurveyCallback - Callback called by modelit.webserver.Server object for processing the survey results.
%
% CALL:
%   SurveyCallback(event)
%
% INPUT:
%   event: <modelit.webserver.HttpExchange>
%     The request data and methods to generate a response.
%
% OUTPUT:
%   No output, the survey result is stored and statuscode 200 (OK) is returned.
%
% EXAMPLE:
%  server = modelit.web.server.Server('localhost', 8081, @SurveyCallback).start() 
%
%  % Open Postman and type: http://localhost:8081/survey in the address bar
%  % Specify HTTP method: POST and optionally fill the body with a json
%  % object representing a survey result.%

%   Copyright 2020 Modelit, www.modelit.nl

% Allow Cross Origin Resource Sharing
event.addResponseHeader('Access-Control-Allow-Origin', '*');

switch lower(event.getRequestMethod)
    case 'post'

        if ~exist(storagepath, 'dir')
            mkdir(storagepath);
            disp(sprintf('directory: %s created', storagepath ));
        else
            disp(sprintf('directory: %s already present', storagepath ));
        end

        json = char(event.getRequestBody()');
        disp(json);
        try
        json = jsondecode(json);
        catch me
            disp(me.message);
        end
disp(json);
        save(fullfile(storagepath, sprintf('message%s', datestr(now, 'yyyymmddHHMMSSFFF'))), 'json');
        % Send the response back to the client
        event.send(200);
    case 'get'
        p = char(event.getPath());
        [p, fname, ext] = fileparts(p);
        
        fname = fullfile(storagepath, p, [fname ext]);
        if exist(fname, 'file')
            response = readBytesFromFile(fname); %this file needs ##readBytesFromFile##
            event.send(200, response);
        else
            event.send(404);
        end
    otherwise
        % 405 Method Not Allowed
        event.send(405);
end



% Send the response back to the client


 
 


