%  generateSelfSignedCertificate - Generate a selfsigned certificate to use   
%  https with the modelit.web.server.Server. This function generates the   
%  following files: cacerts.jks, server.cer and keystore.jks and saves them   
%  in the specified directory.   
%   
%  To use the modelit modelit.web.server.Server as a https server it is necessary to generate   
%  a keystore.jks file. This function does exactly this, you can use its   
%  output arguments to call the modelit.web.server.Server constructor and   
%  create a https with a (selfsigned) certificate.   
%   
%  CALL:   
%    [keystore, keystorepassword, keymanagerpassword] = generateSelfSignedCertificate(directory)   
%   
%  INPUT:   
%    directory: <string>   
%      (optional) path where the keystore is saved. Default value: pwd.   
%   
%  OUTPUT:   
%    keystore: <string>   
%      full path to the keystore.jks file   
%    keystorepassword: <string>   
%      keystore password   
%    keymanagerpassword: <string>   
%      keymanager password   
%   
%  USAGE:   
%   [keystore, keystorepassword, keymanagerpassword] = generateSelfSignedCertificate()   
%   hostname = 'localhost';   
%   port = 8081;   
%   
%   % Create the https server.   
%   server = modelit.web.server.Server(hostname, port, @(e)callback(e), keystore, keystorepassword, keymanagerpassword);   
%   server = start(server);   
%   
%   % Create an HTTP Request (in another Matlab session) or with Postman or   
%   from a browser.   
%   request = modelit.web.client.HttpRequest('get','https://localhost:8081');   
%   response = request.send();   
%   
%  REQUIRES:   
%    keytool:   
%    keytool is a tool to manage (public/private) security keys and certificates and store them in a Java KeyStore file (stored_file_name. jks).   
%    It is provided with any standard JDK / JRE distributions. You can find it under the following folder %JAVA_HOME%\bin .   
   
   
% © Modelit 2006-2023   
% Matlab release: 2023a   
% Date: 2023/03/24 15:18:56   
